@@ -3,6 +3,7 @@ from enum import Enum, auto
 
 import django_filters
 from django.utils.timezone import localdate
+from django.utils.dateparse import parse_date
 from django_filters.rest_framework import DjangoFilterBackend
 from rest_framework.reverse import reverse
 
@@ -110,6 +111,50 @@ class DateFilter(BridgerFilterMixin, django_filters.DateFilter):
     filter_type = "date"
 
 
+class DateRangeFilter(BridgerFilterMixin, django_filters.CharFilter):
+    filter_type = "daterange"
+
+    def __init__(self, *args, **kwargs):
+        self.filter_method = kwargs.pop("method", self.method)
+        super().__init__(*args, **kwargs)
+
+    def get_representation(self, request, name, view):
+        self.key = name
+        representation = {
+            "label": self.label,
+            "type": self.filter_type,
+            "key": self.field_name,
+            "lookup_expr": {"exact": self.field_name,},
+        }
+
+        if self.default:
+            if callable(self.default):
+                default = self.default(field=self, request=request, view=view)
+            else:
+                default = self.default
+
+            representation["default"] = f"{default[0] or ''},{default[1] or ''}"
+
+        return representation
+
+    @staticmethod
+    def method(qs, name, d1=None, d2=None):
+        if d1:
+            qs = qs.filter(**{f"{name}__gte": d1})
+
+        if d2:
+            qs = qs.filter(**{f"{name}__lte": d2})
+
+        return qs
+
+    def filter(self, qs, value):
+        if len(value.split(",")) == 2:
+            start, end = [parse_date(date_string) for date_string in value.split(",")]
+            qs = self.filter_method(qs, self.field_name, start, end)
+
+        return qs
+
+
 class CharFilter(BridgerFilterMixin, django_filters.CharFilter):
     filter_type = "text"
 
