@@ -7,16 +7,24 @@ from bridger.websockets.consumers import AsyncAuthenticatedJsonWebsocketConsumer
 from .models import Notification
 
 
+@database_sync_to_async
+def get_notification(notification_id):
+    return Notification.objects.get(id=notification_id)
+
+
+@database_sync_to_async
+def update_notification(notification_id):
+    Notification.objects.filter(id=notification_id).update(
+        timestamp_received=timezone.now()
+    )
+
+
 class NotificationConsumer(AsyncAuthenticatedJsonWebsocketConsumer):
     async def connect(self):
         await super().connect()
         if "user" in self.scope:
             channel_layer_name = f"notification-{self.scope['user'].id}"
             await self.channel_layer.group_add(channel_layer_name, self.channel_name)
-            # await self.channel_layer.group_send(
-            #     channel_layer_name,
-            #     {"type": "notification.info", "user_id": self.scope["user"].id},
-            # )
 
     async def get_notification_message(self, user):
         num_unreceived, num_unread = await database_sync_to_async(
@@ -40,15 +48,12 @@ class NotificationConsumer(AsyncAuthenticatedJsonWebsocketConsumer):
         await self.send_json({"title": "Notification", "message": notification_message})
 
     async def notification_notify(self, content):
-        await self.send_json(
-            Notification.objects.get(id=content["notification_id"]).to_payload()
+        notification = await get_notification(
+            notification_id=content["notification_id"]
         )
+        await self.send_json(notification.to_payload())
 
     async def receive_json(self, content):
         """ Receives a dict in format of: {"notification_id": <int>} and marks it as received
         """
-        database_sync_to_async(
-            Notification.objects.filter(id=content["notification_id"]).update(
-                timestamp_received=timezone.now()
-            )
-        )
+        await update_notification(notification_id=content["notification_id"])
